import { Modal, Box, Button, TextField, Typography } from "@mui/material";
import { articleStore } from "../../../store/ArticleStore";
import { observer } from "mobx-react-lite";
import { useForm } from "@refinedev/react-hook-form";
import { Controller } from "react-hook-form";
import "easymde/dist/easymde.min.css";
import { memo, useMemo, useEffect } from "react";
import { MarkdownEditor } from "../../MarkdownEditor";
import { Edit } from "@refinedev/mui";
import { languageStore } from "../../../store/LanguageStore";
import { LanguageSwitch } from "../../LanguageSwitch/index";
import { useNavigate } from "react-router";
import { useState } from "react";

const MemoizedSimpleMDE = memo(MarkdownEditor);

const style = {
  position: "absolute",
  top: "50%",
  left: "50%",
  transform: "translate(-50%, -50%)",
  width: "60%",
  bgcolor: "background.paper",
  border: "2px solid #000",
  boxShadow: 24,
  p: 4,
};

export const ArticleEditModal = observer(() => {
  const [articleData, setArticleData] = useState({
    ru: {
      heading: "",
      body: "",
    },
    en: {
      heading: "",
      body: "",
    },
    zh: {
      heading: "",
      body: "",
    },
  });
  const { articleModalOpen, setArticleModalOpenAction, selectedArticleId } =
    articleStore;
  const { language } = languageStore;

  useEffect(() => {
    return () => {
      setArticleModalOpenAction(false);
    };
  }, []);

  const {
    register,
    control,
    formState: { errors },
    saveButtonProps,
    reset,
    setValue,
    watch,
  } = useForm({
    refineCoreProps: {
      resource: "article",
      id: selectedArticleId ?? undefined,
      action: "edit",
      redirect: false,

      onMutationSuccess: () => {
        setArticleModalOpenAction(false);
        reset();
        window.location.reload();
      },
      meta: {
        headers: {
          "Accept-Language": language,
        },
      },
    },
  });

  useEffect(() => {
    if (articleData[language as keyof typeof articleData]?.heading) {
      setValue(
        "heading",
        articleData[language as keyof typeof articleData]?.heading || ""
      );
    }
    if (articleData[language as keyof typeof articleData]?.body) {
      setValue(
        "body",
        articleData[language as keyof typeof articleData]?.body || ""
      );
    }
  }, [language, articleData, setValue]);

  const handleLanguageChange = () => {
    setArticleData((prevData) => ({
      ...prevData,
      [language]: {
        heading: watch("heading") || "",
        body: watch("body") || "",
      },
    }));
  };

  const simpleMDEOptions = useMemo(
    () => ({
      placeholder: "Введите контент в формате Markdown...",
      spellChecker: false,
    }),
    []
  );

  return (
    <Modal
      open={articleModalOpen}
      onClose={() => setArticleModalOpenAction(false)}
      aria-labelledby="modal-modal-title"
      aria-describedby="modal-modal-description"
    >
      <Box sx={style}>
        <Edit
          title={<Typography variant="h5">Редактирование статьи</Typography>}
          headerProps={{
            sx: {
              fontSize: "50px",
            },
          }}
          saveButtonProps={saveButtonProps}
        >
          <LanguageSwitch action={handleLanguageChange} />
          <Box
            component="form"
            sx={{ display: "flex", flexDirection: "column" }}
            autoComplete="off"
          >
            <TextField
              {...register("heading", {
                required: "Это поле является обязательным",
              })}
              error={!!errors.heading}
              helperText={errors.heading?.message as string}
              margin="normal"
              fullWidth
              InputLabelProps={{ shrink: true }}
              type="text"
              name="heading"
              label="Заголовок *"
            />

            <Controller
              control={control}
              name="body"
              rules={{ required: "Это поле является обязательным" }}
              defaultValue=""
              render={({ field: { onChange, value } }) => (
                <MemoizedSimpleMDE
                  value={value}
                  onChange={onChange}
                  options={simpleMDEOptions}
                  className="my-markdown-editor"
                />
              )}
            />
          </Box>
        </Edit>
      </Box>
    </Modal>
  );
});
