import { Stack, Typography, Box, Button } from "@mui/material";
import { useShow } from "@refinedev/core";
import { Show, TextFieldComponent as TextField } from "@refinedev/mui";
import { ReactPhotoSphereViewer } from "react-photo-sphere-viewer";
import sky from "./12414.jpg";
import { MEDIA_TYPES } from "../../lib/constants";
import { TOKEN_KEY } from "../../authProvider";
import { ModelViewer } from "./ModelViewer/index";

export const MediaShow = () => {
  const { query } = useShow({});
  const { data, isLoading } = query;

  const record = data?.data;
  const token = localStorage.getItem(TOKEN_KEY);

  const fields = [
    // {label: 'Название файла', data: 'filename'},
    { label: "Название", data: "media_name" },
    {
      label: "Тип",
      data: "media_type",
      render: (value: number) =>
        MEDIA_TYPES.find((type) => type.value === value)?.label || value,
    },
    // {label: 'ID', data: 'id'},
  ];

  return (
    <Show isLoading={isLoading}>
      <Stack gap={4}>
        {record && record.media_type === 1 && (
          <img
            src={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
            alt={record?.filename}
            style={{
              maxWidth: "100%",
              height: "40vh",
              objectFit: "contain",
              borderRadius: 8,
            }}
          />
        )}

        {record && record.media_type === 2 && (
          <video
            src={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
            style={{
              maxWidth: "50%",

              objectFit: "contain",
              borderRadius: 30,
            }}
            controls
            autoPlay
            muted
          />
        )}
        {record && record.media_type === 3 && (
          <img
            src={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
            alt={record?.filename}
            style={{
              maxWidth: "100%",
              height: "40vh",
              objectFit: "contain",
              borderRadius: 8,
            }}
          />
        )}
        {record && record.media_type === 4 && (
          <img
            src={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
            alt={record?.filename}
            style={{
              maxWidth: "100%",
              height: "40vh",
              objectFit: "contain",
              borderRadius: 8,
            }}
          />
        )}

        {record && record.media_type === 5 && (
          <ReactPhotoSphereViewer
            src={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
            width={"100%px"}
            height={"80vh"}
          />
        )}

        {record && record.media_type === 6 && (
          <ModelViewer
            fileUrl={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
          />
        )}
        {fields.map(({ label, data, render }) => (
          <Stack key={data} gap={1}>
            <Typography variant="body1" fontWeight="bold">
              {label}
            </Typography>
            <TextField
              value={render ? render(record?.[data]) : record?.[data]}
            />
          </Stack>
        ))}
        <Box
          sx={{
            p: 2,
            border: "1px solid text.pimary",
            borderRadius: 2,
            bgcolor: "primary.light",
            width: "fit-content",
          }}
        >
          <Typography
            variant="body1"
            gutterBottom
            sx={{
              color: "#FFFFFF",
            }}
          >
            Доступно для скачивания по ссылке:
          </Typography>
          <Button
            variant="contained"
            href={`${import.meta.env.VITE_KRBL_MEDIA}${
              record?.id
            }/download?token=${token}`}
            target="_blank"
            sx={{ mt: 1, width: "100%" }}
          >
            Скачать медиа
          </Button>
        </Box>
      </Stack>
    </Show>
  );
};
