import {Stack, Typography} from '@mui/material'
import {useShow} from '@refinedev/core'
import {Show, TextFieldComponent as TextField} from '@refinedev/mui'

export const UserShow = () => {
  const {query} = useShow({})
  const {data, isLoading} = query
  const record = data?.data

  const fields = [
    {label: 'Имя', data: 'name'},
    {label: 'Электронная почта', data: 'email'},
    {
      label: 'Администратор',
      data: 'is_admin',
      render: (value: number[][]) => <Typography style={{color: value ? '#48989f' : '#7f6b58'}}>{value ? 'администратор' : 'пользователь'}</Typography>,
    },
  ]

  return (
    <Show isLoading={isLoading}>
      <Stack gap={4}>
        {fields.map(({label, data, render}) => (
          <Stack key={data} gap={1}>
            <Typography variant="body1" fontWeight="bold">
              {label}
            </Typography>
            {render ? render(record?.[data]) : <TextField value={record?.[data]} />}
          </Stack>
        ))}
      </Stack>
    </Show>
  )
}
